# Generated by Django 3.2.20 on 2023-08-01 20:51

from django.db import IntegrityError, migrations, transaction
from django.db.models import Max

from sentry.new_migrations.migrations import CheckedMigration
from sentry.utils.query import RangeQuerySetWrapperWithProgressBar


def backfill_tombstones(apps, schema_editor):
    RegionTombstone = apps.get_model("sentry", "RegionTombstone")
    ControlTombstone = apps.get_model("sentry", "ControlTombstone")

    max_rt = RegionTombstone.objects.aggregate(Max("id"))["id__max"] or 0
    max_ct = ControlTombstone.objects.aggregate(Max("id"))["id__max"] or 0

    for rt in RangeQuerySetWrapperWithProgressBar(RegionTombstone.objects.filter(id__lte=max_rt)):
        try:
            with transaction.atomic("default"):
                ControlTombstone.objects.create(
                    table_name=rt.table_name, object_identifier=rt.object_identifier
                )
        except IntegrityError:
            pass

    for ct in RangeQuerySetWrapperWithProgressBar(ControlTombstone.objects.filter(id__lte=max_ct)):
        try:
            with transaction.atomic("default"):
                RegionTombstone.objects.create(
                    table_name=ct.table_name, object_identifier=ct.object_identifier
                )
        except IntegrityError:
            pass


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production. For
    # the most part, this should only be used for operations where it's safe to run the migration
    # after your code has deployed. So this should not be used for most operations that alter the
    # schema of a table.
    # Here are some things that make sense to mark as dangerous:
    # - Large data migrations. Typically we want these to be run manually by ops so that they can
    #   be monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   have ops run this and not block the deploy. Note that while adding an index is a schema
    #   change, it's completely safe to run the operation after the code has deployed.
    is_dangerous = False

    dependencies = [
        ("sentry", "0535_add_created_date_to_outbox_model"),
    ]

    operations = [
        migrations.RunPython(
            backfill_tombstones,
            migrations.RunPython.noop,
            hints={"tables": ["sentry_controltombstone", "sentry_regiontombstone"]},
        ),
    ]
